import JSZip from "jszip";

/**
 * 下载zip文件并解压
 */
export async function loadzip() {
  return new Promise((resolve, reject) => {
    // 远程加载 resources 文件夹下的 resources.zip 文件, 以二进制方式读取, 从远程服务器直接下载文件同理
    const url = cc.url.raw("resources/resources.zip");
    cc.loader.load({ url, type: "binary" }, async (error: Error, data: any) => {
      if (error) {
        reject(error);
      }

      try {
        // 这里打印出来发现已经转化成了 UInt8Array
        console.log(data);

        // 开始使用jszip操作数据
        const jsZip = new JSZip();
        const zip = await jsZip.loadAsync(data); // 解压 zip 包
        const { files } = zip; // 获取全部文件

        /**
         * 这里将 resources 目录的一张图片和一个json文件解压
         * 读取json文件内容
         * 并将HelloWorld.png渲染出来
         */

        /**
         * 读取json文件
         * 文件内容为
         * {
         *   "hello": "Hello JSZip"
         * }
         */
        if ("test.json" in files) {
          const text = await files["test.json"].async("text"); // jszip以文本形式读取文件内容
          const json = JSON.parse(text);
          console.log(json["hello"]); // 控制台输出 "Hello JSZip"
        }

        /**
         * 读取图片
         */
        if ("HelloWorld.png" in files) {
          const file = await files["HelloWorld.png"].async("base64"); // 以base64形式读取
          const imgData = "data:image/png;base64," + file; // 转化为 dataUrl

          // 将base64图片加载到一个image对象
          const img = new Image();
          img.src = imgData;

          // 并使用texture的 initWithElement方法将image对象转换为texture
          const texture = new cc.Texture2D();
          texture.initWithElement(img);
          texture.handleLoadedTexture();

          // 将texture渲染到画布中预先放置的 New Srpite 节点
          const sprite = cc.find("Canvas/New Sprite");
          sprite.setContentSize(texture.width, texture.height);
          sprite.getComponent(cc.Sprite).spriteFrame = new cc.SpriteFrame(
            texture
          );
        }
        resolve();
      } catch (err) {
        reject(err);
      }
    });
  });
}
